#!/bin/bash

# General policy bin
# Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.

set -e

POLICY_NAME=$1
POLICY_SRC_PATH="$(realpath $2)/"
PRIFIX="$(realpath $3)/"
BOOLEAN_CONFIG='booleans.subs_dist'
POLICYVER='33'

# 对海思工具进行增量化编译适配 注意点: 与海思耦合，需同步海思变更
function support_incremental_compilation()
{
  cd ${POLICY_SRC_PATH}
  echo "selinux tool [info]: start remove duplicate statements in appTemplate.fc file"
  sed -i '/HOME_ROOT\/mdc/d' policy/modules/iamuser/appTemplate.fc
  echo "selinux tool [info]: finish remove duplicate statements in appTemplate.fc file"
  cd -
}

# selinux增量化编译实现
function selinux_incremental_compilation()
{
  cd ${POLICY_SRC_PATH}
  echo "selinux tool [info]: start generate appTemplate package module"
  m4 -D enable_mcs -D distro_redhat -D mls_num_sens=16 -D mls_num_cats=1024 -D mcs_num_cats=1024 -D hide_broken_symptoms -s support/divert.m4 policy/support/file_patterns.spt policy/support/ipc_patterns.spt policy/support/obj_perm_sets.spt policy/support/misc_patterns.spt policy/support/misc_macros.spt policy/support/mls_mcs_macros.spt policy/support/loadable_module.spt support/undivert.m4 tmp/generated_definitions.conf tmp/all_interfaces.conf policy/modules/iamuser/appTemplate.te > tmp/appTemplate.tmp

  /usr/bin/checkmodule -M -m tmp/appTemplate.tmp -o tmp/appTemplate.mod

  m4 -D enable_mcs -D distro_redhat -D mls_num_sens=16 -D mls_num_cats=1024 -D mcs_num_cats=1024 -D hide_broken_symptoms support/divert.m4 policy/support/file_patterns.spt policy/support/ipc_patterns.spt policy/support/obj_perm_sets.spt policy/support/misc_patterns.spt policy/support/misc_macros.spt policy/support/mls_mcs_macros.spt policy/support/loadable_module.spt support/undivert.m4 support/divert.m4 policy/support/file_patterns.spt policy/support/ipc_patterns.spt policy/support/obj_perm_sets.spt policy/support/misc_patterns.spt policy/support/misc_macros.spt policy/support/mls_mcs_macros.spt policy/support/loadable_module.spt support/undivert.m4 policy/modules/iamuser/appTemplate.fc > tmp/appTemplate.mod.fc

  /usr/bin/semodule_package -o appTemplate.pp -m tmp/appTemplate.mod -f tmp/appTemplate.mod.fc
  echo "selinux tool [info]: finish generate appTemplate package module"

  echo "selinux tool [info]: start install appTemplate package module to given path"
  install -m 0644 appTemplate.pp ${PRIFIX}/usr/share/selinux/targeted
  echo "selinux tool [info]: finish install appTemplate package module to given path"

  echo "selinux tool [info]: start install appTemplate package module to policy database"
  /usr/sbin/semodule -v -p ${PRIFIX} -X 100  -s targeted -i ${PRIFIX}/usr/share/selinux/targeted/appTemplate.pp
  echo "selinux tool [info]: finish install appTemplate package module to policy database"

  rm -f ${PRIFIX}/usr/share/selinux/${POLICY_NAME}/*.pp*
  rm -f ${PRIFIX}/etc/selinux/${POLICY_NAME}/src/*.pp*

  /usr/bin/sha512sum ${PRIFIX}/etc/selinux/${POLICY_NAME}/policy/policy.${POLICYVER} | cut -d' ' -f 1 > ${PRIFIX}/etc/selinux/${POLICY_NAME}/.policy.sha512;
  cd -
}

echo "selinux tool [info]: start generate to policy bin"
support_incremental_compilation
selinux_incremental_compilation
echo "selinux tool [info]: finish generate to policy bin"