#!/bin/bash
 
# install ap iam access control list
# Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.

set -e
cur_path=$(cd $(dirname $0);pwd)

:<<!
AP IAM目录设计：
ap_iam_build  <ap_iam_mdc_policy <automatic_generated free_configuration>>
              <ap_iam_usr_policy <automatic_generated free_configuration <template generate>>>
!

# 前置操作
function pre_install_base_config()
{
  cd $cur_path/../../
  if [ ! -e MDC_SDK*.tar.gz ]; then
    echo "ap iam tool [info]: no ap iam sdk exist, finish install mdc ap iam config"
    exit 0
  fi
  if [ "$(ls -l MDC_SDK*.tar.gz | grep -E '180|190|100|120')" == "" ]; then
    echo "ap iam tool [info]: no match sdk exist, finish install mdc ap iam config."
    exit 0
  fi
  cd $cur_path/../
  if [ -d "ap_iam_build" ]; then
    rm -rf ap_iam_build
  fi

  mkdir ap_iam_build
  cd ap_iam_build
  mkdir ap_iam_mdc_policy
  mkdir ap_iam_usr_policy

  cd ap_iam_usr_policy
  mkdir automatic_generated
  mkdir free_configuration
  cd free_configuration
  mkdir template
  mkdir generate
  echo "ap iam tool [info]: finish pre install base ap iam config."
}

# 安装操作，从SDK下载安全访问白名单
function install_cm_access_control_list()
{
  cd $cur_path/../ap_iam_build/ap_iam_mdc_policy
  cp ../../../MDC_SDK*.tar.gz ./
  tar -xzf MDC_SDK*.tar.gz
  if [ ! -d mdc_sdk*/dp_gea/ap_iam_policy ]; then
    echo "ap iam tool [info]: no ap iam config exist, finish install mdc ap iam config."
  else
    cp -rp mdc_sdk*/dp_gea/ap_iam_policy/process/* ./
    cp -rp mdc_sdk*/dp_gea/ap_iam_policy/template/* ./../ap_iam_usr_policy/free_configuration/template
    echo "ap iam tool [info]: finish install base ap iam config."
  fi
}

# 后置安装操作，处理本次安装残留文件
function post_install_base_config()
{
  cd $cur_path/../ap_iam_build/ap_iam_mdc_policy/
  rm -rf mdc_sdk*
  rm MDC_SDK*.tar.gz
  echo "ap iam tool [info]: finish post install mdc base ap iam config."
}

echo "ap iam tool [info]: start install mdc base ap iam config."
pre_install_base_config
install_cm_access_control_list
post_install_base_config
echo "ap iam tool [info]: finish install mdc base ap iam config."