#!/bin/bash

# Label aos filesystem
# Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.

set -e

FILESYSTEM_PATH="$(realpath $1)"
BASE_DIR="$(realpath $2)/"
SELINUXCONFIG=$3
PRODUCT_NAME=$4
CONTEXT_FILES_PATH="${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/files/"

# 文件系统标签设置-权限适配只读文件系统
function adapting_to_readonly_file_systems()
{
  chmod    400 ${FILESYSTEM_PATH}/etc/selinux/config || true
  chmod    555 ${FILESYSTEM_PATH}/etc/selinux/targeted/ || true
  chmod -R 444 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/files/* || true
  chmod -R 444 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/users/* || true
  chmod    444 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/* || true
  chmod    555 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/files/ || true
  chmod    555 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/users/ || true
  chmod -R 400 ${FILESYSTEM_PATH}/etc/selinux/targeted/policy/* || true
  chmod    400 ${FILESYSTEM_PATH}/etc/selinux/targeted/.policy.sha512 || true
  chmod    400 ${FILESYSTEM_PATH}/etc/selinux/targeted/* || true
  chmod    555 ${FILESYSTEM_PATH}/etc/selinux/targeted/contexts/ || true

  if [ -f "${FILESYSTEM_PATH}/etc/sysconfig/selinux" ]; then
    chmod 400 ${FILESYSTEM_PATH}/etc/sysconfig/selinux || true
  fi
  if [ -f "${FILESYSTEM_PATH}/usr/lib/rpm/macros.d/macros.selinux-policy" ]; then
    chmod 400 ${FILESYSTEM_PATH}/usr/lib/rpm/macros.d/macros.selinux-policy || true
  fi
  if [ -f "${FILESYSTEM_PATH}/usr/lib/tmpfiles.d/selinux-policy.conf" ]; then
    chmod 400 ${FILESYSTEM_PATH}/usr/lib/tmpfiles.d/selinux-policy.conf || true
  fi
  if [ -f "${FILESYSTEM_PATH}/usr/share/selinux/packages/" ]; then
    chmod -R 400 ${FILESYSTEM_PATH}/usr/share/selinux/packages/ || true
  fi
  if [ -f "${FILESYSTEM_PATH}/usr/share/selinux/targeted/" ]; then
    chmod -R 400 ${FILESYSTEM_PATH}/usr/share/selinux/targeted/ || true
  fi
  if [ -f "${FILESYSTEM_PATH}/var/lib/selinux/targeted/" ]; then
    chmod -R 400 ${FILESYSTEM_PATH}/var/lib/selinux/targeted/ || true
  fi
  echo "selinux tool [info]: finish adapting to readonly file systems"
}

# 文件系统标签设置-用户包无contexts文件
function label_filesystem_function_without_contexts()
{
  cd ${BASE_DIR}
  cat ${BASE_DIR}etc/selinux/targeted/contexts/files/file_contexts.homedirs > ./aosPolicy.fc
  cat ${BASE_DIR}etc/selinux/targeted/contexts/files/file_contexts >> ./aosPolicy.fc
  sed -i "s|/opt/usr/app/1|${FILESYSTEM_PATH}|g" aosPolicy.fc
  setfiles -c etc/selinux/targeted/policy/policy.33 aosPolicy.fc ${FILESYSTEM_PATH}
  rm ./aosPolicy.fc
  echo "selinux tool [info]: finish label filesystem without contexts"
  cd -
}

# 文件系统标签设置-用户包有contexts文件
function label_filesystem_function_with_contexts()
{
  cd ${BASE_DIR}
  cat ${CONTEXT_FILES_PATH}file_contexts.homedirs > ./aosPolicy.fc
  cat ${CONTEXT_FILES_PATH}file_contexts >> ./aosPolicy.fc
  sed -i "s|/opt/usr/app/1|${FILESYSTEM_PATH}|g" aosPolicy.fc

  if [ ! -f "${FILESYSTEM_PATH}/etc/selinux/config" ]; then
    echo "
# SELINUX can set to be disabled(close selinux), permissive(just warning) or enforcing(enable selinux)
SELINUX=disabled
# SELINUXTYPE must set to be targeted
SELINUXTYPE=targeted

" > ${FILESYSTEM_PATH}/etc/selinux/config
  fi

  sed -i "s/SELINUX=.*$/SELINUX=${SELINUXCONFIG}/g" ${FILESYSTEM_PATH}/etc/selinux/config || true
  setfiles -c etc/selinux/targeted/policy/policy.33 aosPolicy.fc ${FILESYSTEM_PATH}

  adapting_to_readonly_file_systems
  rm ./aosPolicy.fc
  echo "selinux tool [info]: finish label filesystem with contexts"
  cd -
}

# 文件系统标签设置实现
function label_filesystem_function()
{
  if [ ! "${PRODUCT_NAME}" = "MDC" ]; then
    echo "selinux tool [error]: production name is not mdc"
    exit 1
  fi

  if [ ! -d "${CONTEXT_FILES_PATH}" ]; then
    label_filesystem_function_without_contexts
  else
    label_filesystem_function_with_contexts
  fi
}

echo "selinux tool [info]: start label aos filesystem"
label_filesystem_function
echo "selinux tool [info]: start label aos filesystem"

