#!/bin/bash

# Selinux install base policy
# Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.

set -e

cur_path=$(cd $(dirname $0);pwd)

# 前置安装操作，用于环境检查及历史残留清理
function pre_install_base_policy()
{
  cd $cur_path/../../
  if [ ! -e MDC_SDK*.tar.gz ]; then
    echo "selinux tool [info]: no selinux sdk exist, finish install mdc base policy"
    exit 0
  fi
  cd $cur_path/../
  if [ -d "selinux_build" ]; then
    rm -rf selinux_build
  fi
  echo "selinux tool [info]: finish pre install base policy"
}

# 安装操作，从SDK下载基础策略库
function install_base_policy()
{
  cd $cur_path/../
  mkdir selinux_build
  cd selinux_build
  mkdir selinux_usr_policy
  mkdir selinux_base_policy

  cd selinux_base_policy
  cp ../../../MDC_SDK*.tar.gz ./
  if [ "$(ls -l MDC_SDK*.tar.gz | grep -E '180|190|100|120|707')" == "" ]; then
    echo "ap iam tool [info]: no match sdk exist, finish install mdc selinux config."
    return
  fi
  tar -xzf MDC_SDK*.tar.gz
  cp mdc_sdk*/dp_gea/mdc_selinux_policy/selinux-policy-35.5-3.h20.noarch.rpm ./
  rpm2cpio selinux-policy-35.5-3.h20.noarch.rpm | cpio -id
  cp -rp mdc_sdk*/dp_gea/mdc_selinux_policy/targeted/* etc/selinux/targeted/
  cp -rp mdc_sdk*/dp_gea/mdc_selinux_policy/tmp etc/selinux/targeted/src/
  cp -rp mdc_sdk*/dp_gea/mdc_selinux_policy/usr ./
  cp -rp mdc_sdk*/dp_gea/mdc_selinux_policy/var ./
  mkdir etc/selinux/targeted/policy/originPolicy
  cp -rp mdc_sdk*/dp_gea/mdc_selinux_policy/targeted/policy/policy.33 etc/selinux/targeted/policy/originPolicy

  echo "selinux tool [info]: finish install base policy"
}

# 后置安装操作，处理本次安装残留文件
function post_install_base_policy()
{
  cd $cur_path/../selinux_build/selinux_base_policy/
  rm -rf mdc_sdk*
  rm -rf MDC_SDK*.tar.gz
  rm -rf selinux-policy-35.5-3.h20.noarch.rpm

  apt-get install zip -y
  cd $cur_path
  if [ ! -d "base_library.zip" ]; then
    unzip -q base_library.zip -d base_library
    rm -rf base_library.zip
    mv base_library base_library.zip
  fi
  echo "selinux tool [info]: finish post install mdc base policy"
}

echo "selinux tool [info]: start install mdc base policy"
pre_install_base_policy
install_base_policy
post_install_base_policy
echo "selinux tool [info]: finish install mdc base policy"
