#!/bin/bash

# Selinux install environment ubuntu
# Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.

set -e

cur_path=$(cd $(dirname $0);pwd)

function config_parameter_check()
{
  if [ ! -f "/boot/config-$(uname -r)" ]; then
    echo "selinux tool [error]: /boot/config-$(uname -r) not exists"
    exit 1
  fi

  if [ "$(cat /boot/config-$(uname -r) |grep -v '\#' |grep -w CONFIG_SECURITY_SELINUX |cut -d '=' -f2)" == "y" ] && \
  [ "$(cat /boot/config-$(uname -r) |grep -v '\#' |grep -w CONFIG_SECURITY_SELINUX_BOOTPARAM |cut -d '=' -f2)" == "y" ] && \
  [ "$(cat /boot/config-$(uname -r) |grep -v '\#' |grep -w CONFIG_SECURITY_SELINUX_DEVELOP |cut -d '=' -f2)" == "y" ] && \
  [ "$(cat /boot/config-$(uname -r) |grep -v '\#' |grep -w CONFIG_SECURITY_SELINUX_AVC_STATS |cut -d '=' -f2)" == "y" ] && \
  [ "$(cat /boot/config-$(uname -r) |grep -v '\#' |grep -w CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE |cut -d '=' -f2)" == "1" ]; then
    echo "selinux tool [info]: system selinux config check is ok"
  else 
    echo "selinux tool [error]: please check system selinux config"
    exit 1
  fi
}

function apt_get_and_network_check()
{
  sudo apt-get update -y
  if [ $? -eq 0 ];then
    echo "selinux tool [info]: check apt-get is ok"
  else
    echo "selinux tool [error]: please check apt-get"
    exit 1
  fi

  timeout 10 wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/libsepol-3.3-2.oe2203.src.rpm
  if [ $? -ne 0 ]; then
      echo "selinux tool [error]: please check network"
      exit 1
  fi
  rm -f libsepol-3.3-2.oe2203.src.rpm
}

function install_selinux_basic_and_utils()
{
  apt-get install selinux-policy-default -y
  apt-get install selinux-basics -y
  apt-get install selinux-utils -y
  apt-get install policycoreutils-dev -y
  apt-get install selinux-policy-dev -y
  selinux-activate -y
  echo "selinux tool [info]: finish install selinux basic and utils"
}

function install_selinux_compile_dependency()
{
  apt-get install gettext -y
  apt-get install libpcre3 -y
  apt-get install libpcre3-dev -y
  apt-get install libbz2-dev -y
  apt-get install libaudit-dev -y
  apt-get install flex -y
  apt-get install pkg-config -y
  apt-get install bison -y
  apt-get install rpm2cpio -y
  pip install cython==0.29.36
  echo "selinux tool [info]: finish install selinux compile dependency"
}

function config_character_set()
{
  export LC_ALL=C.UTF-8
}

function install_openeuler_libsepol()
{
  cd $cur_path
  rm -rf libsepol
  mkdir libsepol
  cd libsepol
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/libsepol-3.3-2.oe2203.src.rpm
  rpm2cpio libsepol-3.3-2.oe2203.src.rpm | cpio -id
  tar -zxvf libsepol-3.3.tar.gz
  cd libsepol-3.3/
  make
  make install

  cd /usr/lib/x86_64-linux-gnu/
  if [ ! -e libsepol.so.2 ]; then
    cp /usr/lib/libsepol.so.2 /usr/lib/x86_64-linux-gnu/
  fi
  if [ ! -e libsepol.a ]; then
    cp /usr/lib/libsepol.a /usr/lib/x86_64-linux-gnu/
  fi
  cd /usr/lib/x86_64-linux-gnu/pkgconfig/
  if [ ! -e libsepol.pc ]; then
    cp /usr/lib/pkgconfig/libsepol.pc /usr/lib/x86_64-linux-gnu/pkgconfig/
  fi

  cd $cur_path
  rm -f libsepol-3.3-2.oe2203.src.rpm
  rm -rf libsepol
  echo "selinux tool [info]: finish install openEuler libsepol"
}

function install_openeuler_libselinux()
{
  cd $cur_path
  rm -rf libselinux
  mkdir libselinux
  cd libselinux
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/libselinux-3.3-1.oe2203.src.rpm
  rpm2cpio libselinux-3.3-1.oe2203.src.rpm | cpio -id
  tar -zxvf libselinux-3.3.tar.gz
  cd libselinux-3.3/
  make
  make install

  cd /usr/lib/x86_64-linux-gnu/
  if [ ! -e libselinux.so.1 ]; then
    cp /usr/lib/libselinux.so.1 /usr/lib/x86_64-linux-gnu/
  fi

  cd $cur_path
  rm -f libselinux-3.3-1.oe2203.src.rpm
  rm -rf libselinux
  echo "selinux tool [info]: finish install openEuler libselinux"
}

function install_openeuler_libsemanage()
{
  cd $cur_path
  rm -rf libsemanage
  mkdir libsemanage
  cd libsemanage
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/libsemanage-3.3-3.oe2203.src.rpm
  rpm2cpio libsemanage-3.3-3.oe2203.src.rpm | cpio -id
  tar -zxvf libsemanage-3.3.tar.gz
  cd libsemanage-3.3/
  make
  make install

  cd /usr/lib/x86_64-linux-gnu/
  if [ ! -e libsemanage.so.2 ]; then
    cp /usr/lib/libsemanage.so.2 /usr/lib/x86_64-linux-gnu/
  fi

  cd $cur_path
  rm -f libsemanage-3.3-3.oe2203.src.rpm
  rm -rf libsemanage
  echo "selinux tool [info]: finish install openEuler libsemanage"
}

function install_openeuler_checkpolicy()
{
  cd $cur_path
  rm -rf checkpolicy
  mkdir checkpolicy
  cd checkpolicy
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/checkpolicy-3.3-1.oe2203.src.rpm
  rpm2cpio checkpolicy-3.3-1.oe2203.src.rpm | cpio -id
  tar -zxvf checkpolicy-3.3.tar.gz
  cd checkpolicy-3.3/
  make
  make install
  cd $cur_path
  rm -f checkpolicy-3.3-1.oe2203.src.rpm
  rm -rf checkpolicy
  echo "selinux tool [info]: finish install openEuler checkpolicy"
}

function install_openeuler_policycoreutils()
{
  cd $cur_path
  rm -rf policycoreutils
  mkdir policycoreutils
  cd policycoreutils
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/update/source/Packages/policycoreutils-3.3-2.oe2203.src.rpm
  rpm2cpio policycoreutils-3.3-2.oe2203.src.rpm | cpio -id
  tar -zxvf policycoreutils-3.3.tar.gz
  cd selinux-policycoreutils-3.3/policycoreutils/
  make
  make install
  cd $cur_path
  rm -f policycoreutils-3.3-2.oe2203.src.rpm
  rm -rf policycoreutils
  echo "selinux tool [info]: finish install openEuler policycoreutils"
}

function install_openeuler_semodule_utils()
{
  cd $cur_path
  rm -rf semodule_utils
  mkdir semodule_utils
  cd semodule_utils
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/update/source/Packages/policycoreutils-3.3-2.oe2203.src.rpm
  rpm2cpio policycoreutils-3.3-2.oe2203.src.rpm | cpio -id
  tar -zxvf policycoreutils-3.3.tar.gz
  cd selinux-policycoreutils-3.3/semodule-utils/
  make
  make install
  cd $cur_path
  rm -f policycoreutils-3.3-2.oe2203.src.rpm
  rm -rf semodule_utils
  echo "selinux tool [info]: finish install openEuler semodule utils"
}

function install_openeuler_setools()
{
  cd $cur_path
  rm -rf setools
  mkdir setools
  cd setools
  wget --no-check-certificate https://repo.openeuler.org/openEuler-22.03-LTS/source/Packages/setools-4.4.0-2.oe2203.src.rpm
  rpm2cpio setools-4.4.0-2.oe2203.src.rpm | cpio -id
  tar -zxvf 4.4.0.tar.gz
  cd setools-4.4.0/
  python3 setup.py build_ext
  python3 setup.py build
  python3 setup.py install
  cd $cur_path
  rm -f setools-4.4.0-2.oe2203.src.rpm
  rm -rf setools
  echo "selinux tool [info]: finish install openEuler setools"
}

function prepare_for_selinux_relable()
{
  touch /.autorelabel
}

# 检测selinux开发环境配置与清理残余
function selinux_environment_check()
{
  config_parameter_check
  apt_get_and_network_check

  systemctl stop apparmor
  timeout 30 apt-get remove apparmor -y
  echo "selinux tool [info]: finish selinux environment check"
}

# selinux开发环境安装操作，安装基础依赖包
function install_selinux_environment()
{
  install_selinux_basic_and_utils > /dev/null
  install_selinux_compile_dependency > /dev/null
  echo "selinux tool [info]: finish install selinux basic and compile dependency"

  config_character_set > /dev/null
  install_openeuler_libsepol > /dev/null
  install_openeuler_libselinux > /dev/null
  install_openeuler_libsemanage > /dev/null
  install_openeuler_checkpolicy > /dev/null
  install_openeuler_policycoreutils > /dev/null
  install_openeuler_semodule_utils > /dev/null
  install_openeuler_setools > /dev/null
  prepare_for_selinux_relable > /dev/null
  echo "selinux tool [info]: finish install openEuler lib dependency"
}

echo "selinux tool [info]: start install selinux environment"
selinux_environment_check
install_selinux_environment
echo "selinux tool [info]: finish install selinux environment"
