#!/bin/bash

# Perform the action of deploying pack environment in project.
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2023. All rights reserved.

set -e

repo=$(cat /etc/apt/sources.list | grep -v '#' | grep deb | head -1 | awk -F '/' '{print $3}')

#部署docker和docker-compose
function install_docker() {
  apt-get update
  apt install -y docker.io python3-wheel python3 python3-pip
  python3 -m pip install pip3
  pip3 install setuptools-rust
  pip3 install --upgrade pip
  pip3 install docker-compose
  systemctl restart docker
  docker pull ubuntu:latest
  if [ $? -ne 0 ]; then
    echo "cicd [ERROR]: docker network failure, please configure docker_image_proxy"
    exit 1
  else
    dest="REPO_URL"
    sed -i "s/${dest}/http:\/\/${repo}/g" Dockerfile
    docker build -t cicd-buildenv:1.0.0 .
    docker-compose up -d
  fi
}


#检查命令函数
function check() {
  if $($1 >/dev/null 2>&1); then
    tag=True
  else
    tag=False
  fi
}

#调用selinux脚本模块
function selinux_install() {
    if [ -f bin/selinux_install_environment_ubuntu.sh ]&&\
        [ -f  bin/selinux_install_base_policy.sh ]; then
        ./bin/selinux_install_environment_ubuntu.sh
        if [ $? -ne 0 ]; then
            echo "cicd [ERROR] selinux_install_environment_ubuntu failed !"
        else
            echo "cicd [INFO] selinux_install_environment_ubuntu succssed !"
        fi
        ./bin/selinux_install_base_policy.sh 
        if [ $? -ne 0 ]; then
            echo "cicd [ERROR] selinux_install_base_policy failed !"
        else
            echo "cicd [INFO] selinux_install_base_policy succssed !"
        fi
    fi
}

#调用ap iam部署脚本
function ap_iam_install() {
    if [ -f bin/install_access_control_list.sh ]; then
        ./bin/install_access_control_list.sh
        if [ $? -ne 0 ]; then
            echo "cicd [ERROR]: install access control list failed !"
        else
            echo "cicd [INFO]: install access control list succeed !"
        fi
    fi
}

#主函数
check "docker ps" && check "docker-compose"
if [ "$tag" == "False" ]; then
  install_docker
else
  echo "cicd tool[INFO]: don't need to deploy docker"
  function deploy() {
    dest="REPO_URL"
    sed -i "s/${dest}/http:\/\/${repo}/g" Dockerfile
    #优化deploy重复执行支持自动修改apt为本地源
    if [ -f Dockerfile ]; then
      repo_url=$(cat Dockerfile | grep deb | head -1 | awk '{print $4}' | awk -F '/' '{print $3}')
      if [ "$repo_url" != "$repo" ]; then
        dest=$repo_url
        sed -i "s/${dest}/${repo}/g" Dockerfile
      fi
    fi
    docker_id=$(docker ps | awk '/cicd-buildenv:1.0.0/''{print $1}')
    check "docker stop $docker_id"
    if [ "$tag" == "False" ]; then
      docker build -t cicd-buildenv:1.0.0 .
      docker-compose up -d
      #增加启动后关闭docker
      if [ $? -eq 0 ]; then
        docker_id=$(docker ps | awk '/cicd-buildenv:1.0.0/''{print $1}')
        docker stop $docker_id
      fi
    fi
  }
  deploy
fi

selinux_install

ap_iam_install

#增加dm签名工具安装，增加工具在此处添加
apt install -y cryptsetup-bin